==> img0ch-2.1.21.tar.bz2: img0ch/_template/type/search_text.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title>img0ch - fS</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js" charset="UTF-8"></script>
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
jQuery(function(){
    jQuery("//input[@name='query']").get(0).focus();
});
function redir(element) {
    app.redirectRenderer( element,
        { "theme": "<?cs var:html_escape(BBS_TYPE_THEME) ?>" } );
    return true;
}
//]]>
</script>
<style type="text/css">
@charset "shift_jis";
.clear { clear: both; }
.from { text-align: right; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.res_body {
  font-size: 12pt;
  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
  line-height: 110% !important;
}
div#searchForm {
  text-align: center;
  margin-left: auto;
  margin-right: auto;
}
</style>
<?cs var:META ?>
</head>
<body>

<?cs if:Banner ?>
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<hr class="sep" />
<?cs /if ?>

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">u<?cs var:html_escape(BBS_TITLE) ?>v̌fS</span>
 </h2>
 <div class="form">
  <form action="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi" method="post">
  <div class="caption">
   <p>
    <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">Ytt@C</a>
   </p>
  </div>
  <div id="searchForm" class="section">
   <div class="field">
    <input type="text" name="query" value="<?cs var:Query ?>" size="50" />
    <select name="type">
     <option value="subject"<?cs if:SelectedSubject ?> selected="selected"<?cs /if ?>>Xbh̑薼</option>
     <option value="FROM"<?cs if:SelectedFrom ?> selected="selected"<?cs /if ?>>O</option>
     <option value="mail"<?cs if:SelectedMail ?> selected="selected"<?cs /if ?>>[</option>
     <option value="date"<?cs if:SelectedDate ?> selected="selected"<?cs /if ?>></option>
     <option value="id"<?cs if:SelectedId ?> selected="selected"<?cs /if ?>>ID</option>
     <option value="MESSAGE"<?cs if:SelectedMessage ?> selected="selected"<?cs /if ?>>{</option>
    </select>
   </div>
   <div><input type="submit" value="Jn" <?cs if:Disabled ?>disabled="disabled" <?cs /if ?>/></div>
   <div class="hidden_field"><input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" /></div>
  </div>
  </form>
 </div>
</div>

<?cs if:Query ?>
<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">
   u<?cs var:html_escape(Query) ?>v̌ʁF<?cs var:html_escape(Total) ?>
  </span>
 </h2>
 <div class="body">
  <div class="caption">
   <p>
<?cs if:Prev ?><a href="<?cs var:CGIURI ?>/img0ch-st.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(QueryURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>&amp;type=<?cs var:html_escape(SearchType) ?>">&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:CGIURI ?>/img0ch-st.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(QueryURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>&amp;type=<?cs var:html_escape(SearchType) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:CGIURI ?>/img0ch-st.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(QueryURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>&amp;type=<?cs var:html_escape(SearchType) ?>">&gt;&gt;</a><?cs /if ?>
   </p>
  </div>
  <?cs each:item = Result ?>
  <div class="section" id="r_<?cs var:html_escape(item.resno) ?>">
   <div class="caption res_header">
    <?cs var:html_escape(item.resno) ?>
    OF<span class="commentator">
    <?cs if:item.mail ?>
    <a href="mailto:<?cs var:html_escape(item.mail) ?>" rel="nofollow"><b><?cs var:item.name ?></b></a>
    <?cs else ?>
    <span class="nomail"><b><?cs var:item.name ?></b></span>
    <?cs /if ?>
    </span>:<span class="commenttime"><?cs var:html_escape(item.date) ?></span>
   </div>
   <p class="res_body"><?cs var:item.text ?></p>
   <div class="from"><hr /><a href="<?cs var:CGIURI ?>/read.cgi/<?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.subject ?></a><?cs if:item.found ?>&nbsp;(<?cs var:item.count ?>X̂<?cs var:item.found ?>Y)<?cs /if ?></div>
   </div>
  <?cs /each ?>
 </div>
</div>
<?cs /if ?>

<div class="footer" id="VERSION"><a href="http://img0ch.sourceforge.jp">img0ch-st.cgi - img0ch BBS</a></div>

</body>
</html>

==> img0ch-3.0.0.tar.bz2: img0ch/_template/type/search_text.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title>img0ch - fS</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="screen" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<![CDATA[
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
jQuery(function(){
    jQuery("//input[@name='query']").get(0).focus();
});
function redir(element) {
    app.redirectRenderer( element,
        { "theme": "<?cs var:html_escape(BBS_TYPE_THEME) ?>" } );
    return true;
}
//]]>
</script>
<style type="text/css">
@charset "shift_jis";
.clear { clear: both; }
.from { text-align: right; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
.res_body {
  font-size: 12pt;
  font-family: "Mona","IPA i[ PSVbN","IPA MONAPGOTHIC","MS PGothic","lr oSVbN","MS P޼","MS PSVbN",sans-serif;
  line-height: 110% !important;
}
div#searchForm {
  text-align: center;
  margin-left: auto;
  margin-right: auto;
}
</style>
<?cs var:META ?>
</head>
<body>

<?cs if:Banner ?>
<div class="day" id="mainBanner">
 <h2><span class="title">m</span></h2>
 <div class="body">
  <div class="section">
   <?cs var:Banner ?>
  </div>
 </div>
</div>
<hr class="sep" />
<?cs /if ?>

<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">u<?cs var:html_escape(BBS_TITLE) ?>v̌fS</span>
 </h2>
 <div class="form">
  <form action="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi" method="post">
  <div class="caption">
   <p>
    <a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
    <a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">Ytt@C</a>
   </p>
  </div>
  <div id="searchForm" class="section">
   <div class="field">
    <input type="text" name="query" value="<?cs var:Query ?>" size="50" />
    <select name="type">
     <option value="subject"<?cs if:SelectedSubject ?> selected="selected"<?cs /if ?>>Xbh̑薼</option>
     <option value="FROM"<?cs if:SelectedFrom ?> selected="selected"<?cs /if ?>>O</option>
     <option value="mail"<?cs if:SelectedMail ?> selected="selected"<?cs /if ?>>[</option>
     <option value="date"<?cs if:SelectedDate ?> selected="selected"<?cs /if ?>></option>
     <option value="id"<?cs if:SelectedId ?> selected="selected"<?cs /if ?>>ID</option>
     <option value="MESSAGE"<?cs if:SelectedMessage ?> selected="selected"<?cs /if ?>>{</option>
    </select>
   </div>
   <div><input type="submit" value="Jn" <?cs if:Disabled ?>disabled="disabled" <?cs /if ?>/></div>
   <div class="hidden_field"><input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>" /></div>
  </div>
  </form>
 </div>
</div>

<?cs if:Query ?>
<div class="day">
 <h2 class="thread_header">
  <span class="title thread_subject">
   u<?cs var:html_escape(Query) ?>v̌ʁF<?cs var:html_escape(Total) ?>
  </span>
 </h2>
 <div class="body">
  <div class="caption">
   <p>
<?cs if:Prev ?><a href="<?cs var:CGIURI ?>/img0ch-st.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(QueryURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>&amp;type=<?cs var:html_escape(SearchType) ?>">&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:CGIURI ?>/img0ch-st.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(QueryURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>&amp;type=<?cs var:html_escape(SearchType) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:CGIURI ?>/img0ch-st.cgi?bbs=<?cs var:html_escape(BBS) ?>&amp;word=<?cs var:html_escape(QueryURLEscaped) ?>&amp;entries=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>&amp;type=<?cs var:html_escape(SearchType) ?>">&gt;&gt;</a><?cs /if ?>
   </p>
  </div>
  <?cs each:item = Result ?>
  <div class="section" id="r_<?cs var:html_escape(item.resno) ?>">
   <div class="caption res_header">
    <?cs var:html_escape(item.resno) ?>
    OF<span class="commentator">
    <?cs if:item.mail ?>
    <a href="mailto:<?cs var:html_escape(item.mail) ?>" rel="nofollow"><b><?cs var:item.name ?></b></a>
    <?cs else ?>
    <span class="nomail"><b><?cs var:item.name ?></b></span>
    <?cs /if ?>
    </span>:<span class="commenttime"><?cs var:item.date ?></span>
   </div>
   <p class="res_body"><?cs var:item.text ?></p>
   <div class="from"><hr /><a href="<?cs var:CGIURI ?>/read.cgi/<?cs var:BBS ?>/<?cs var:item.key ?>/l50" onclick="redir(this)"><?cs var:item.subject ?></a><?cs if:item.found ?>&nbsp;(<?cs var:item.count ?>X̂<?cs var:item.found ?>Y)<?cs /if ?></div>
   </div>
  <?cs /each ?>
 </div>
</div>
<?cs /if ?>

<div class="footer" id="VERSION"><a href="http://img0ch.sourceforge.jp">img0ch-st.cgi - img0ch BBS</a></div>

</body>
</html>
